pytomography.corrections.correction - PyTomography 0.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# `pytomography.corrections.correction`

## Module Contents

### Classes

`CorrectionNet` | Correction net is the parent class for all correction networks used in reconstruction. Subclasses must implement the `forward` method.

class pytomography.corrections.correction.CorrectionNet(device='cpu')

  Bases: `torch.nn.Module`

  Correction net is the parent class for all correction networks used in reconstruction. Subclasses must implement the `forward` method.

  Parameters:

    device (str) – Pytorch device used for computation

  initialize_network(object_meta, image_meta)

    Initalizes the correction network using the object/image metadata

    Parameters:

      - object_meta (ObjectMeta) – Object metadata.

      - image_meta (ImageMeta) – Image metadata.

    Return type:

      None

  abstract forward(x)

    Abstract method; must be implemented in subclasses to apply a correction to an object/image and return it

    Parameters:

      x (torch.tensor) –